=======
Credits
=======

Development Lead
----------------

* Christophe Duong <chris@aiscalate.com>

Contributors
------------

None yet. Why not be the first?

Components
----------

This software uses the following open source components:

* Jupyter-Project_ notebook, lab, etc under BSD-3-Clause_ license
* Jupytext_ under MIT_ license
* Docker_
* Jupyter-Docker-Stacks_ under BSD-3-Clause_ license
* Airflow_ under Apache-2_ license
* Docker-Airflow_ under Apache-2_ license
* Papermill_ under BSD-3-Clause_ license
* This project was created with Cookiecutter_ under BSD-3-Clause_ license
* with the `audreyr/cookiecutter-pypackage`_ project template.
* with the `ionelmc/cookiecutter-pylibrary`_ project template
* PyHOCON_ under Apache-2_ license

.. _Jupyter-Project: https://jupyter.org/
.. _Jupytext: https://github.com/mwouts/jupytext
.. _Docker: https://www.docker.com/
.. _Jupyter-Docker-Stacks: https://github.com/jupyter/docker-stacks
.. _Airflow: https://github.com/apache/airflow
.. _Docker-Airflow: https://github.com/puckel/docker-airflow
.. _Papermill: https://github.com/nteract/papermill
.. _PyHOCON: https://github.com/chimpler/pyhocon
.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`ionelmc/cookiecutter-pylibrary`: https://github.com/ionelmc/cookiecutter-pylibrary

.. _BSD-3-Clause: https://opensource.org/licenses/BSD-3-Clause
.. _MIT: https://opensource.org/licenses/MIT
.. _Apache-2: https://opensource.org/licenses/Apache-2.0
